pm4py.algo.conformance.decomp\_alignments package
=================================================

Module contents
---------------

.. automodule:: pm4py.algo.conformance.decomp_alignments
   :members:
   :undoc-members:
   :show-inheritance:
